my_lm: Fitting Linear Models

Description Usage Arguments Value Examples

View source: R/my_lm.R

Description

Used to fit linear models. It can be used to carry out regression, single stratum analysis of variance and analysis of covariance.

Usage

1

Arguments

formula:

a formula class object, similar to lm().

data:

input data frame.

Value

table similar to the coefficient table from summary() with rows for each coefficient (including the (Intercept)!) and columns for the Estimate, Std. Error, t value, and Pr(>|t|). There should be row and column names.

Examples

1
my_lm(mpg ~ hp + wt, data = mtcars)

SabrinaYuY/project3 documentation built on Dec. 18, 2021, 12:02 p.m.