my_rf_cv: Random Forest Function

Description Usage Arguments Value Examples

View source: R/my_rf_cv.R

Description

This function would use random forest algorithm to predict quantitive output

Usage

1

Arguments

k

Numeric input indicates number of folds.

Value

a numeric representing the mean standard error across all the folds.

Examples

1
2

SabrinaYuY/project3 documentation built on Dec. 18, 2021, 12:02 p.m.