Description Usage Arguments Value Examples
Used to fit linear models. It can be used to carry out regression, single stratum analysis of variance and analysis of covariance.
1 |
formula: |
a formula class object, similar to lm(). |
data: |
input data frame. |
table similar to the coefficient table from summary() with rows for each coefficient (including the (Intercept)!) and columns for the Estimate, Std. Error, t value, and Pr(>|t|). There should be row and column names.
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.