Description Usage Arguments Value Examples
This function would use random forest algorithm to predict quantitive output
1 | my_rf_cv(k)
|
k |
Numeric input indicates number of folds. |
a numeric representing the mean standard error across all the folds.
1 2 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.